.. _dm:

****************************************
Dispersion Measure (`baseband_tasks.dm`)
****************************************

Radio waves travelling through ionized interstellar medium experience a
frequency-dependent slowing of the signal group velocity known as dispersion.
The `~baseband_tasks.dm` module provides functionality for storing and
utilizing the dispersion measure, which is related to the delay in arrival time
of radio signals due to the cumulative effects of dispersion.

.. _dm_api:

Reference/API
=============

.. automodapi:: baseband_tasks.dm
   :no-inherited-members: